@@ -19,11 +19,6 @@ class BucketRouting:
                             bucket_operations.create_bucket()
                         except KeyboardInterrupt:
                             Py_version_manager.py_print(" ")
-                        except Exception as e:
-                            if(str(e)=="'data'" or str(e)=="'code'"):
-                                Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
-                            else:
-                                raise e
 
         elif self.arguments.bucket_commands == 'delete':
             bucket_operations = bucketCrud(alias=self.arguments.alias)
@@ -32,12 +27,7 @@ class BucketRouting:
                             bucket_operations.delete_bucket()
                         except KeyboardInterrupt:
                             Py_version_manager.py_print(" ")
-                        except Exception as e:
-                            if(str(e)=="'data'" or str(e)=="'code'"):
-                                Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
-                            else:
-                                raise e
-        
+                        
         elif self.arguments.bucket_commands == 'list':
             bucket_operations = bucketCrud(alias=self.arguments.alias)
             if(bucket_operations.possible):
@@ -45,10 +35,6 @@ class BucketRouting:
                             bucket_operations.list_bucket()
                         except KeyboardInterrupt:
                             Py_version_manager.py_print(" ")
-                        except Exception as e:
-                            if(str(e)=="'data'" or str(e)=="'code'"):
-                                Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
-                            else:
-                                raise e
+                        
 
 
