@@ -2,8 +2,7 @@ import subprocess
 
 from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.config.config import AuthConfig
-from e2e_cli.core.alias_service import get_user_cred
-
+from e2e_cli.core.alias_service import get_user_cred, option_check
 
 class ConfigRouting:
     def __init__(self, arguments):
@@ -15,14 +14,16 @@ class ConfigRouting:
 
 
         elif self.arguments.config_commands == 'add':
-            if(self.arguments.alias=="all"):
-                Py_version_manager.py_print("sorry all is an reserve keyword for listing all registered alias/user")
+            if(self.arguments.alias=="file"):
+                path=Py_version_manager.py_input("input the file path : ")
+                auth_config_object = AuthConfig()
+                auth_config_object.adding_config_file(path)
                 return
-            
+
             try:
                 api_key = Py_version_manager.py_input("Enter your api key: ")
                 auth_token = Py_version_manager.py_input("Enter your auth token: ")
-                auth_config_object = AuthConfig(alias=self.arguments.alias,
+                auth_config_object = AuthConfig(alias=option_check(self.arguments.alias),
                                                     api_key=api_key,
                                                     api_auth_token=auth_token)
                 auth_config_object.add_to_config()
@@ -47,8 +48,10 @@ class ConfigRouting:
 
 
         elif self.arguments.config_commands == 'view':
-            for item in list(get_user_cred("all", 1)):
-                 Py_version_manager.py_print(item)
- 
+            if(self.arguments.alias=="all"):
+                for item in list(get_user_cred("all", 1)):
+                    Py_version_manager.py_print(item)
+            else:
+                    Py_version_manager.py_print("Action not allowed")
             
 
