@@ -4,6 +4,20 @@ import platform
 
 from e2e_cli.core.py_manager import Py_version_manager
 
+
+def option_check(alias):
+    # constant, reserved keywords
+    RESERVES=["all", "config", "node", "bucket", "lb", "dbaas", "create", "get", "list", "update", "edit", "delete", "file"]
+
+    if(alias not in RESERVES):
+        if(alias.startswith("@")):
+            return alias.lstrip(alias[0])
+        else:
+            return 
+    else:
+        return alias
+
+
 class AliasServices:
     def __init__(self, alias):
         self.alias = alias
@@ -27,6 +41,7 @@ def system_file():
 
 def get_user_cred(name, x=0):
     
+    name=option_check(name)
     file= system_file()
 
     # try :
