@@ -63,16 +63,17 @@ class LBClass:
         else:
             alias = self.kwargs["alias"]
             lb_services_object = LBServices(alias)
-            lb_delete_response_object = lb_services_object.delete_lb()
+            lb_delete_response_object = lb_services_object.delete_lb_sevice()
             if lb_delete_response_object["message"] == "Valid alias":
                 Py_version_manager.py_print("  Your instance have been deleted")
                 Py_version_manager.py_print(
                     "To check the state of the LB you can run e2e_cli lb list <alias> "
                 )
+            elif lb_delete_response_object["message"] == "Aborted":
+                Py_version_manager.py_print(lb_delete_response_object["message"])
             elif lb_delete_response_object["code"] == 404:
                 Py_version_manager.py_print("" + lb_delete_response_object["message"])
-            elif lb_delete_response_object["message"] == "Failure":
-                pass
+            
 
 
     def edit_lb(self):
@@ -91,6 +92,6 @@ class LBClass:
             elif lb_edit_response_object["code"] == 404:
                 Py_version_manager.py_print("" + lb_edit_response_object["message"])
             elif lb_edit_response_object["message"] == "Failure":
-                pass
+                Py_version_manager.py_print("It appears you have selected wrong options")
             else:
                 Py_version_manager.py_print("Please provide a valid Alias")
