@@ -19,9 +19,10 @@ class LBRouting:
             except KeyboardInterrupt:
                 Py_version_manager.py_print(" ")
             except Exception as e:
-                            e=str(e)
-                            if(e=="'data'" or e=="'code'"):
+                            if(str(e)=="'data'" or str(e)=="'code'"):
                                 Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
+                            else:
+                                raise e
 
         elif self.arguments.lb_commands == 'list' or self.arguments.lb_commands == 'ls':
             lb_class_object = LBClass(alias=self.arguments.alias)
@@ -30,9 +31,10 @@ class LBRouting:
             except KeyboardInterrupt:
                 Py_version_manager.py_print(" ")
             except Exception as e:
-                            e=str(e)
-                            if(e=="'data'" or e=="'code'"):
+                            if(str(e)=="'data'" or str(e)=="'code'"):
                                 Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
+                            else:
+                                raise e
 
         elif self.arguments.lb_commands == 'delete':
             lb_class_object = LBClass(alias=self.arguments.alias)
@@ -41,9 +43,10 @@ class LBRouting:
             except KeyboardInterrupt:
                 Py_version_manager.py_print(" ")
             except Exception as e:
-                            e=str(e)
-                            if(e=="'data'" or e=="'code'"):
+                            if(str(e)=="'data'" or str(e)=="'code'"):
                                 Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
+                            else:
+                                raise e
 
         elif self.arguments.lb_commands == 'edit':
             lb_class_object = LBClass(alias=self.arguments.alias)
@@ -52,6 +55,7 @@ class LBRouting:
             except KeyboardInterrupt:
                 Py_version_manager.py_print(" ")
             except Exception as e:
-                            e=str(e)
-                            if(e=="'data'" or e=="'code'"):
+                            if(str(e)=="'data'" or str(e)=="'code'"):
                                 Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
+                            else:
+                                raise e
