@@ -7,7 +7,7 @@ from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.core.request_service import Request
 from e2e_cli.core.alias_service import AliasServices
 from e2e_cli.core.helper_service import Checks
-from e2e_cli.node.node import NodeCrud
+from e2e_cli.node.node_crud.node import NodeCrud
 
 
 class LBServices:
