@@ -34,10 +34,12 @@ class Main:
 
     def node(self, parser):
         node_sub_parser = parser.add_subparsers(title="node Commands", dest="node_commands")
+        node_action=parser.add_argument('-action', '--action', help="Type of action to be performed your node")
         node_create_sub_parser = node_sub_parser.add_parser("create", help="To create a new node")
         node_delete_sub_parser = node_sub_parser.add_parser("delete", help="To delete a specific node")
         node_list_sub_parser = node_sub_parser.add_parser("list", help="To get a list of all nodes")
         node_get_sub_parser = node_sub_parser.add_parser("get", help="To get a list of all nodes")
+        self.FormatUsageCommand(node_action, "node", "actions")
         self.FormatUsageCommand(node_create_sub_parser, "node", "create")
         self.FormatUsageCommand(node_delete_sub_parser, "node", "delete")
         self.FormatUsageCommand(node_list_sub_parser, "node", "list")
